@@ -7,8 +7,13 @@ get_var_label <- function(varId, lang = "pl") {
   var_suffix <- var_suffix %>%
     utils::head(1) %>%
     dplyr::select(dplyr::starts_with("n"))
-
-  var_suffix <- paste(var_suffix, collapse = " - ")
+  
+  temp <- list()
+  for(val in 1:length(var_prefix$dimensions)){
+    temp[val] <- paste(var_prefix$dimensions[val], var_suffix[val], sep = ":")
+  }
+  
+  var_suffix <- paste(temp, collapse = ", ")
   variable_label <- paste(var_prefix$name, var_suffix, sep = " - ")
   variable_label
 }
@@ -32,3 +37,14 @@ get_attr_label <- function(attrId, lang = "pl") {
 #' @keywords internal
 nchar_length <- function(x) {`if`(any(is.na(x)), 0, nchar(x)) }
 
+#' @keywords internal
+add_attribute_labels <- function(x, lang = "pl") {
+  attributes <- unique(x$attrId)
+  attribute_labels <- lapply(attributes, get_attr_label, lang = lang)
+  names(attribute_labels) <- attributes
+  df <- dplyr::mutate(x, attributeDescription = as.character(attribute_labels[as.character(x$attrId)]))
+  df
+}
+
+#' @keywords internal
+is.error <- function(x) inherits(x, "try-error")
